Exasol Toolbox
#####################

.. image:: https://img.shields.io/pypi/v/exasol-toolbox
     :target: https://pypi.org/project/exasol-toolbox/
     :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/exasol-toolbox
    :target: https://pypi.org/project/exasol-toolbox
    :alt: PyPI - Python Version

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Formatter - Black

.. image:: https://img.shields.io/badge/imports-isort-ef8336.svg
    :target: https://pycqa.github.io/isort/
    :alt: Formatter - Isort

.. image:: https://img.shields.io/badge/typing-mypy-blue
    :target: https://github.com/PyCQA/pylint
    :alt: Pylint

.. image:: https://img.shields.io/badge/pylint-7.8-green
    :target: https://github.com/PyCQA/pylint
    :alt: Pylint

.. image:: https://img.shields.io/pypi/l/exasol-bucketfs
     :target: https://opensource.org/licenses/MIT
     :alt: License

.. image:: https://img.shields.io/github/last-commit/nicoretti/python-toolbox
     :target: https://pypi.org/project/exasol-toolbox/
     :alt: Last Commit


🚀 Features
------------

* Centrally managed standard tasks
    - code formatting & upgrading
    - linting
    - type-checking
    - unit-tests
    - integration-tests
    - coverage
    - documentation

* Centrally manged core workflows
    - workspace/project verification
    - build and publish releases
    - build and publish documentation

* Configurable & Extensible
    - Project configuration
    - Event hooks

🔌️ Prerequisites
-----------------

- `Python <https://www.python.org/>`_ >= 3.8

💾 Installation
----------------

.. code-block:: shell

    pip install exasol-toolbox

📚 Documentation
----------------

The latest documentation can be found `here <https://nicoretti.github.io/python-toolbox/index.html>`_.
